package com.ruoyi.ems.service;

import java.util.List;

import com.ruoyi.ems.domain.ElecAttr;

/**
 * 服务区用电属性Service接口
 * 
 * @author ruoyi
 * @date 2024-07-23
 */
public interface IElecAttrService
{
    /**
     * 查询服务区用电属性
     * 
     * @param id 服务区用电属性主键
     * @return 服务区用电属性
     */
     ElecAttr selectElecAttrById(Long id);

    /**
     * 查询服务区用电属性列表
     * 
     * @param areaElectricityAttr 服务区用电属性
     * @return 服务区用电属性集合
     */
     List<ElecAttr> selectElecAttrList(ElecAttr areaElectricityAttr);

    /**
     * 新增服务区用电属性
     * 
     * @param areaElectricityAttr 服务区用电属性
     * @return 结果
     */
     int insertElecAttr(ElecAttr areaElectricityAttr);

    /**
     * 修改服务区用电属性
     * 
     * @param areaElectricityAttr 服务区用电属性
     * @return 结果
     */
     int updateElecAttr(ElecAttr areaElectricityAttr);

    /**
     * 批量删除服务区用电属性
     * 
     * @param ids 需要删除的服务区用电属性主键集合
     * @return 结果
     */
     int deleteElecAttrByIds(Long[] ids);

    /**
     * 删除服务区用电属性信息
     * 
     * @param id 服务区用电属性主键
     * @return 结果
     */
     int deleteElecAttrById(Long id);
}
